===================================================================
:mod:`tensor.elemwise` --  Tensor Elemwise
===================================================================

.. testsetup::

   from aesara.tensor.elemwise import *

.. module:: tensor.elemwise
   :platform: Unix, Windows
   :synopsis: Tensor Elemwise
.. moduleauthor:: LISA

.. automodule:: aesara.tensor.elemwise
    :members:
